"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _getLog = require("./get-log");

var _eventstoreBase = require("@resolve-js/eventstore-base");

var _errors = require("./errors");

var _makePostgresClient = _interopRequireDefault(require("./make-postgres-client"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const connect = async (pool, {
  Postgres,
  escapeId,
  escape,
  fullJitter,
  executeStatement
}, config) => {
  var _eventsTableName, _snapshotsTableName, _secretsTableName, _subscribersTableName;

  const log = (0, _getLog.getLog)('connect');
  log.debug('configuring postgres client');
  let {
    databaseName,
    eventsTableName,
    snapshotsTableName,
    secretsTableName,
    subscribersTableName,
    // eslint-disable-next-line prefer-const
    ...connectionOptions
  } = config;
  eventsTableName = (_eventsTableName = eventsTableName) !== null && _eventsTableName !== void 0 ? _eventsTableName : 'events';
  snapshotsTableName = (_snapshotsTableName = snapshotsTableName) !== null && _snapshotsTableName !== void 0 ? _snapshotsTableName : 'snapshots';
  secretsTableName = (_secretsTableName = secretsTableName) !== null && _secretsTableName !== void 0 ? _secretsTableName : 'secrets';
  subscribersTableName = (_subscribersTableName = subscribersTableName) !== null && _subscribersTableName !== void 0 ? _subscribersTableName : 'subscribers';
  const oldConnection = pool.connection;

  if (oldConnection !== undefined) {
    pool.connection = undefined;
    oldConnection.end(err => {
      if (err) log.error(`Error during disconnection before reconnection: ${err}`);
    });
  }

  const connection = (0, _makePostgresClient.default)(pool, Postgres, connectionOptions);

  try {
    await connection.connect();
    Object.assign(pool, {
      databaseName,
      eventsTableName,
      snapshotsTableName,
      secretsTableName,
      connectionOptions,
      subscribersTableName,
      Postgres,
      fullJitter,
      executeStatement: executeStatement.bind(null, pool),
      escapeId,
      escape,
      connection
    });

    if (pool.executeStatement != null) {
      await pool.executeStatement('SELECT 0 AS "defunct"');
    }
  } catch (error) {
    if ((0, _errors.isServiceBusyError)(error)) {
      const busyError = new _eventstoreBase.ServiceBusyError(error.message);
      busyError.stack = error.stack;
      throw busyError;
    } else if (error instanceof Error) {
      const connectionError = new _eventstoreBase.ConnectionError(error.message);
      connectionError.stack = error.stack;
      throw connectionError;
    } else {
      throw error;
    }
  }

  log.debug('connection to postgres databases established');
};

var _default = connect;
exports.default = _default;
//# sourceMappingURL=connect.js.map